@@ -387,7 +387,8 @@ static bool validDataFormat (ActorAgent::ActorType type, const ByteArray &ba) {
                 (ba.size () > 4 &&
                  !strncmp (ba.data (), "RIFF", 4))); // falsely seen as text
         if (!kill && ba.size() > 14) {
-            String ct = MimeType::findByContent (ba.data(), ba.size ());
+            int sz = ba.size () > 512 ? 512 : ba.size();
+            String ct = MimeType::findByContent (ba.data(), sz);
             kill = !ct.startsWith ("text/") ||
                 (!strncasecmp (ba.data (), "<html", 5) || // html admin
                  !strncasecmp (ba.data (), "<!doctype html", 14));
