@@ -62,7 +62,9 @@ static gulong               gst_bus_sync;
 static gulong               gst_bus_async;
 static GMainLoop           *event_loop;
 static guint                position_tag;
+static int                  seek_start;
 static guint                current_volume;
+static gboolean             has_video_codec;
 
 static gboolean cb_play (gpointer data);
 static gboolean cb_buffering (gpointer data);
@@ -107,20 +109,21 @@ cb_error (GstElement * play,
 
 static void gstCapsSet (GstPad *pad, GParamSpec *pspec, gpointer data) {
     GstCaps *caps = gst_pad_get_negotiated_caps (pad);
+    const GstStructure *structure;
     (void) pspec;
     (void ) data;
 
     if (!caps)
         return;
   /*QApplication::postEvent (gstapp, new QEvent ((QEvent::Type) event_video));*/
-    const GstStructure * s = gst_caps_get_structure (caps, 0);
-    if (s) {
+    structure = gst_caps_get_structure (caps, 0);
+    if (structure) {
         const GValue *par;
         Dimension *dim;
 
-        gst_structure_get_int (s, "width", &movie_width);
-        gst_structure_get_int (s, "height", &movie_height);
-        if ((par = gst_structure_get_value (s, "pixel-aspect-ratio"))) {
+        gst_structure_get_int (structure, "width", &movie_width);
+        gst_structure_get_int (structure, "height", &movie_height);
+        if ((par = gst_structure_get_value (structure, "pixel-aspect-ratio"))) {
             int num = gst_value_get_fraction_numerator (par),
                 den = gst_value_get_fraction_denominator (par);
 
@@ -221,12 +224,22 @@ cb_expose (GtkWidget * w, GdkEventExpose * ev, GstElement * e)
 
 static void gstTag (const GstTagList *lst, const gchar *tag, gpointer data) {
     (void) data;
-    fprintf (stderr, "Tag: %s\n", tag);
-    if (gst_tag_get_type (tag) == G_TYPE_STRING && !strcmp (tag, "title")) {
+    if (gst_tag_get_type (tag) == G_TYPE_STRING) {
         gchar *val = NULL;
         gst_tag_list_get_string (lst, tag, &val);
-        output ("ICY Info: StreamTitle='%s';\n", val);
+        if (!strcmp (tag, "title")) {
+            output ("ICY Info: StreamTitle='%s';\n", val);
+        } else if (!strcmp (tag, "audio-codec")) {
+            output ("ID_AUDIO_CODEC=%s;\n", val);
+        } else if (!strcmp (tag, "video-codec")) {
+            output ("ID_VIDEO_CODEC=%s\n", val);
+            has_video_codec = TRUE;
+        } else {
+            fprintf (stderr, "Tag: %s=%s\n", tag, val);
+        }
         g_free (val);
+    } else {
+        fprintf (stderr, "Tag: %s\n");
     }
 }
 
@@ -423,7 +436,7 @@ static void play () {
     if (!mrl || !mrl[0])
         return;
     movie_length = movie_width = movie_height = 0;
-    gst_elm_play = gst_element_factory_make ("playbin", playbin_name);
+    gst_elm_play = gst_element_factory_make ("playbin2", playbin_name);
     if (!gst_elm_play) {
         fprintf (stderr, "couldn't create playbin\n");
         goto fail;
@@ -682,11 +695,16 @@ static gboolean cb_buffering (gpointer data) {
 
 static gboolean cb_playing (gpointer data) {
     (void)data;
-    output ("Start playback tag:%u\n", position_tag);
-    position_tag = g_timeout_add (500, cb_position, NULL);
-    fprintf(stderr, "  tag:%u\n", position_tag);
-    volume (50);
-    notified_playing = TRUE;
+    if (!notified_playing) {
+        notified_playing = TRUE;
+        if (!has_video_codec)
+            output ("Video: no video\n");
+        output ("Start playback\n");
+        position_tag = g_timeout_add (500, cb_position, NULL);
+        volume (30);
+        if (seek_start > 0)
+            seek (seek_start * 10);
+    }
     return FALSE;
 }
 
@@ -817,6 +835,18 @@ static gboolean watchStdin (GIOChannel *src, GIOCondition cond, gpointer data) {
     return TRUE;
 }
 
+#include <execinfo.h>
+#include <signal.h>
+static void sig_abort(int i) {
+    void* trace[256];
+    int n = backtrace(trace, 256);
+    (void)i;
+    if (!n)
+        return;
+    backtrace_symbols_fd (trace, n, 2);
+    exit(0);
+}
+
 int main (int argc, char **argv) {
     int i;
     int xpos    = 0;
@@ -835,6 +865,10 @@ int main (int argc, char **argv) {
     GPollFD poll_fd;
     GSource *x11_source;
 
+    signal(SIGABRT, sig_abort);
+    signal(SIGINT, sig_abort);
+    signal(SIGSEGV, sig_abort);
+
     if (!XInitThreads ()) {
         fprintf (stderr, "XInitThreads () failed\n");
         return 1;
@@ -865,6 +899,8 @@ int main (int argc, char **argv) {
             ;
         } else if (!strcmp (argv [i], "-v")) {
             verbose = TRUE;
+        } else if (!strcmp (argv [i], "-ss") && ++i < argc) {
+            seek_start = strtol (argv[i], NULL, 10);
         } else if (!strncmp (argv [i], "-h", 2)) {
             fprintf (stderr, "usage: %s [-vo (xv|xshm)] [-ao <audio driver>] [-dvd-device <device>] [-vcd-device <device>] [-v] [(-wid|-window-id) <window>] [(-root|-window)]] [<url>]\n", argv[0]);
         } else if (strncmp (argv [i], "-", 1)) {
@@ -886,7 +922,9 @@ int main (int argc, char **argv) {
                 xpos, ypos, width, height, 1, 0, 0);
     fprintf (stderr, "init wid %u created:%d\n", (unsigned)wid, window_created);
     XSelectInput (display, wid,
-                  (PointerMotionMask | ExposureMask | KeyPressMask | ButtonPressMask | StructureNotifyMask)); /* | SubstructureNotifyMask));*/
+                  (PointerMotionMask | ExposureMask |
+                   KeyPressMask | /*ButtonPressMask |*/
+                   StructureNotifyMask)); /* | SubstructureNotifyMask));*/
 
     if (window_created) {
         XMapRaised(display, wid);
