@@ -11,7 +11,6 @@
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 #include <pango/pango-font.h>
-#include <libgnomevfs/gnome-vfs-init.h>
 #include <gtkhtml/gtkhtml.h>
 #define DBUS_API_SUBJECT_TO_CHANGE
 #include <dbus/dbus.h>
@@ -283,6 +282,7 @@ bool cb_window_expose (GtkWidget *w, GdkEventExpose *ev, Application *app) {
         gtk_paned_set_position (app->vsplit_view, VSPLIT);
         gtk_widget_hide (GTK_WIDGET (app->tb_progress));
         gtk_widget_hide (GTK_WIDGET (app->tb_item_playlist_commit));
+        gtk_widget_hide (app->info_viewport);
     }
     return false;
 }
@@ -597,7 +597,7 @@ int main (int argc, char* argv[]) {
     Application *app;
     int i;
 
-    gnome_vfs_init ();  /* calls g_thread_init(NULL);*/
+    g_thread_init (NULL);
     /* Create needed variables */
     signal(SIGABRT, sig_abort);
     signal(SIGINT, sig_abort);
@@ -743,7 +743,6 @@ int main (int argc, char* argv[]) {
     osso_mime_unset_cb (app->osso_context);
     osso_deinitialize (app->osso_context);
     app_destroy (app);
-    gnome_vfs_shutdown ();
 
     /* Exit */
     return 0;
