@@ -149,15 +149,14 @@ public:
 };
 
 class KMPLAYER_NO_EXPORT Generator
-    : public FileDocument, public UnixProcessListener {
+    : public FileDocument, public UnixProcessListener, public IOJobListener {
 public:
     Generator (KMPlayer::Control *src)
         : FileDocument (id_node_gen_document, String (), src),
-          unix_process (NULL), data (NULL) {}
+          unix_process (NULL), input_job (NULL), data (NULL), buffer (NULL) {}
     void activate ();
     void begin ();
     void deactivate ();
-    void message (KMPlayer::MessageType msg, void *content=NULL);
     Node *childFromTag (const String & tag);
     KDE_NO_EXPORT const char *nodeName () const { return "generator"; }
 
@@ -165,6 +164,10 @@ public:
     void writeEvent (UnixProcess *);
     void processExited (UnixProcess *);
 
+    void jobData (IOJob *job, ByteArray &data);
+    void jobResult (IOJob *job);
+    void redirected (IOJob*, const String&) {}
+
 private:
     String genReadProcess (Control *ctrl, Node *n);
     String genReadInput (Control *ctrl, Node *n);
@@ -173,9 +176,10 @@ private:
     String genReadAsk (Control *ctr, Node *n);
 
     UnixProcess *unix_process;
+    IOJob *input_job;
     TextStream *data;
+    ByteArray *buffer;
     String process;
-    unsigned write_pos;
     bool canceled;
     bool quote;
 };
