@@ -40,7 +40,7 @@ KDE_NO_CDTOR_EXPORT RP::Imfl::~Imfl () {
 KDE_NO_EXPORT void RP::Imfl::closed () {
     for (Node *n = firstChild (); n; n = n->nextSibling ())
         if (RP::id_node_head == n->id) {
-            Attribute *a = static_cast <Element *> (n)->attributes ()->first ();
+            Attribute *a = static_cast <Element *> (n)->attributes ().first ();
             for (; a; a = a->nextSibling ()) {
                 if (StringPool::attr_width == a->name ()) {
                     size.width = a->value ().toInt ();
@@ -273,14 +273,13 @@ KDE_NO_EXPORT void RP::TimingsBase::activate () {
     setState (state_activated);
     x = y = w = h = 0;
     srcx = srcy = srcw = srch = 0;
-    for (Attribute *a = attributes()->first (); a; a = a->nextSibling ()) {
+    for (Attribute *a = attributes().first (); a; a = a->nextSibling ()) {
         if (a->name () == StringPool::attr_target) {
-            for (Node *n = parentNode()->firstChild(); n; n= n->nextSibling()) {
+            for (Node *n = parentNode()->firstChild(); n; n= n->nextSibling())
                 if (n->isElementNode () &&
                         static_cast <Element *> (n)->
                             getAttribute ("handle") == a->value ())
                     target = n->self ();
-            }
         } else if (a->name () == "start") {
             int dur;
             parseTime (a->value ().lower (), dur);
