@@ -126,23 +126,21 @@ Control::~Control () {
 
 void Control::init () {
     unsigned int ver, rel, req, evb, err;
-    glob_t gt;
     struct stat st;
 
-    use_xvideo = !glob ("/usr/lib/libXv.so*", GLOB_ERR|GLOB_NOSORT, 0, &gt);
-    globfree (&gt);
+    use_xvideo = true;
    //media_server = new OssoMediaServer (this, m_app->osso_context, use_xvideo);
-    MPlayer *gst = new MPlayer (this, false);
+    MPlayer *gst = new MPlayer (this, "osso-media-server");
     gst->setPlayer ("kgstplayer");
     gst->setAudioDriver ("pulse");
     gst->setVideoDriver ("xv");
     media_server = gst;
-    mplayer = new MPlayer (this, use_xvideo);
+    mplayer = new MPlayer (this, "mplayer");
 #ifdef __ARMEL__
     npp = new NpPlayer (this);
 #endif
     downloader = new Downloader (this, m_app);
-    String p = m_config->readEntry (GCONF_KEY_PLAYER, OssoMediaServer::myname);
+    String p = m_config->readEntry (GCONF_KEY_PLAYER, "osso-media-server");
     setProcess ((const char *) p);
 
     if (use_xvideo)
@@ -534,8 +532,12 @@ bool Control::setProcess (const char *pname) {
         menu = m_app->menu_item_media_server;
     }
     gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu), true);
-    if (old_process)
-        old_process->quit ();
+    if (old_process) {
+        if (old_process == m_process)
+            old_process->stop ();
+        else
+            old_process->quit ();
+    }
     setUseXVideo (use_xvideo);
 }
 
@@ -559,7 +561,7 @@ bool Control::setProcess (Mrl *mrl) {
     if (pname.isEmpty () && !mrl->mimetype.isEmpty ())
         pname = processForMimetype (m_config, mrl->mimetype);
     if (pname.isEmpty ())
-        pname = m_config->readEntry (GCONF_KEY_PLAYER, OssoMediaServer::myname);
+        pname = m_config->readEntry (GCONF_KEY_PLAYER, "osso-media-server");
     if (!m_process || pname != m_process->name ()) {
         setProcess ((const char *) pname);
         changed = true;
@@ -1008,15 +1010,18 @@ void KMPlayer::jump (Node *n, Control *ctr) {
         ctr->updatePlaylistView ();
 }
 
-void app_set_info_content (Application *app, const char *utf8, bool plaintext) {
-    if (!plaintext && utf8[0]) {
+void app_set_info_content (Application *app, const char *s, bool plaintext) {
+    if (!plaintext) {
         gtk_widget_hide (app->info_viewport);
         gtk_widget_show (app->html_viewport);
-        gtk_html_load_from_string (GTK_HTML (app->html_infopanel_view),utf8,-1);
+        if (!s[0])
+            gtk_html_load_empty (GTK_HTML (app->html_infopanel_view));
+        else
+            gtk_html_load_from_string(GTK_HTML(app->html_infopanel_view), s,-1);
     } else {
         gtk_widget_hide (app->html_viewport);
         gtk_text_buffer_set_text (gtk_text_view_get_buffer
-                (GTK_TEXT_VIEW (app->infopanel_view)), utf8, -1);
+                (GTK_TEXT_VIEW (app->infopanel_view)), s, -1);
         gtk_widget_show (app->info_viewport);
     }
 }
