@@ -709,10 +709,11 @@ String Mrl::absolutePath () {
     if (p > -1 && p < 15)
         return src;
     String path = src;
-    if (!path.isEmpty() && !path.startsWith ("tv:/")) {
+    if (!path.isEmpty()) {
         for (Node *e = parentNode (); e; e = e->parentNode ()) {
             Mrl *mrl = e->mrl ();
-            if (mrl && !mrl->src.isEmpty () && mrl->src != src) {
+            if (mrl && !mrl->src.isEmpty () &&
+                    mrl->src != src && !mrl->src.startsWith ("Playlist:/")) {
                 path = URL (mrl->absolutePath (), path).url ();
                 break;
             }
