@@ -45,7 +45,7 @@ class MediaInfo;
  * \sa: self()
  */
 template <class T>
-class KMPLAYER_EXPORT Item {
+class KMPLAYER_NO_EXPORT Item {
     friend class SharedPtr<T>;
     friend class WeakPtr<T>;
 public:
@@ -106,7 +106,7 @@ private:
  * A double linked list of ListNodeBase<T> nodes
  */
 template <class T>
-class KMPLAYER_EXPORT List {
+class KMPLAYER_NO_EXPORT List {
 public:
     List () {}
     List (typename Item<T>::SharedType f, typename Item<T>::SharedType l)
@@ -134,7 +134,7 @@ protected:
  * The linkage is a shared nextSibling and a weak previousSibling.
  */
 template <class T>
-class KMPLAYER_EXPORT ListNodeBase : public Item <T> {
+class KMPLAYER_NO_EXPORT ListNodeBase : public Item <T> {
     friend class List<T>;
 public:
     T* nextSibling () const { return m_next.ptr (); }
@@ -160,7 +160,7 @@ public:
  * The linkage is a shared firstChild and weak parentNode.
  */
 template <class T>
-class KMPLAYER_EXPORT TreeNode : public ListNodeBase <T> {
+class KMPLAYER_NO_EXPORT TreeNode : public ListNodeBase <T> {
 public:
     void insertBefore (T *c, T *b);
     void appendChild (T *c);
@@ -184,7 +184,7 @@ protected:
 /**
  * Attribute having a name/value pair for use with Elements
  */
-class KMPLAYER_EXPORT Attribute : public ListNodeBase <Attribute> {
+class KMPLAYER_NO_EXPORT Attribute : public ListNodeBase <Attribute> {
 public:
     KDE_NO_CDTOR_EXPORT Attribute () {}
     Attribute (const TrieString &ns, const TrieString &n, const String &v);
@@ -372,7 +372,7 @@ TextStream & operator << (TextStream &out, const XMLStringlet &txt);
  |-->state_activated<-->state_began<-->state_finished-->state_deactivated-->|
   In scope            begin event    end event         Out scope
  */
-class KMPLAYER_EXPORT Node : public TreeNode <Node> {
+class KMPLAYER_NO_EXPORT Node : public TreeNode <Node> {
     friend class DocumentBuilder;
 public:
     enum State {
@@ -524,7 +524,7 @@ const short id_node_svg = 29;
 /*
  * Element node, XML node that can have attributes
  */
-class KMPLAYER_EXPORT Element : public Node {
+class KMPLAYER_NO_EXPORT Element : public Node {
 public:
     ~Element ();
     void setAttributes (const AttributeList &attrs);
@@ -569,7 +569,7 @@ inline Node *findChildWithId (const Node *p, const short id) {
     return NULL;
 }
 
-class KMPLAYER_EXPORT Title : public Element {
+class KMPLAYER_NO_EXPORT Title : public Element {
 protected:
     Title (NodePtr & d, short id=0) : Element (d, id ) {}
 
@@ -583,7 +583,7 @@ public:
 /**
  * Element representing a playable link, like URL to a movie or playlist.
  */
-class KMPLAYER_EXPORT Mrl : public Title {
+class KMPLAYER_NO_EXPORT Mrl : public Title {
 protected:
     Mrl (NodePtr & d, short id=0);
     Node *childFromTag (const String & tag);
@@ -635,7 +635,7 @@ public:
 /**
  * Document listener interface
  */
-class KMPLAYER_EXPORT PlayListNotify {
+class KMPLAYER_NO_EXPORT PlayListNotify {
 public:
     /**
      * Element has activated or deactivated notification
@@ -659,7 +659,7 @@ public:
     virtual void enableRepaintUpdaters (bool enable, unsigned int off_time)=0;
 };
 
-struct KMPLAYER_EXPORT Command {
+struct KMPLAYER_NO_EXPORT Command {
     virtual void apply (struct timeval &timeout) = 0;
     virtual bool postponable () const = 0;
     virtual int delay () const = 0;
@@ -669,7 +669,7 @@ struct KMPLAYER_EXPORT Command {
 /*
  *  A generic type for posting messages
  **/
-class KMPLAYER_EXPORT Posting : public Command {
+class KMPLAYER_NO_EXPORT Posting : public Command {
 public:
     KDE_NO_CDTOR_EXPORT Posting (Node *n, Node *tgt, MessageType msg)
         : source (n), target (tgt), message (msg) {}
@@ -745,7 +745,7 @@ struct KMPLAYER_NO_EXPORT CommandData {
 /**
  * The root of the DOM tree
  */
-class KMPLAYER_EXPORT Document : public Mrl {
+class KMPLAYER_NO_EXPORT Document : public Mrl {
     friend class Postpone;
 public:
     Document (const String &, PlayListNotify * notify = 0L);
@@ -873,7 +873,7 @@ public:
 /**
  * Represents XML text, like "some text" in '<foo>some text</foo>'
  */
-class KMPLAYER_EXPORT TextNode : public Node {
+class KMPLAYER_NO_EXPORT TextNode : public Node {
 public:
     TextNode (NodePtr & d, const String & s, short _id = id_node_text);
     KDE_NO_CDTOR_EXPORT ~TextNode () {}
@@ -890,7 +890,7 @@ protected:
 /**
  * Represents cdata sections, like "some text" in '<![CDATA[some text]]>'
  */
-class KMPLAYER_EXPORT CData : public TextNode {
+class KMPLAYER_NO_EXPORT CData : public TextNode {
 public:
     CData (NodePtr & d, const String & s);
     KDE_NO_CDTOR_EXPORT ~CData () {}
@@ -916,7 +916,7 @@ protected:
 /**
  * just some url, can get a SMIL, RSS, or ASX childtree
  */
-class KMPLAYER_EXPORT GenericURL : public Mrl {
+class KMPLAYER_NO_EXPORT GenericURL : public Mrl {
 public:
     GenericURL(NodePtr &d, const String &s, const String &n=String());
     KDE_NO_EXPORT const char * nodeName () const { return "url"; }
@@ -926,7 +926,7 @@ public:
 /**
  * Non url mrl
  */
-class KMPLAYER_EXPORT GenericMrl : public Mrl {
+class KMPLAYER_NO_EXPORT GenericMrl : public Mrl {
 public:
     KDE_NO_CDTOR_EXPORT GenericMrl (NodePtr & d) : Mrl (d), node_name ("mrl") {}
     GenericMrl(NodePtr &d, const String &s,
@@ -941,9 +941,9 @@ public:
     String node_name;
 };
 
-KMPLAYER_EXPORT
+KMPLAYER_NO_EXPORT
 void readXML (NodePtr root, TextStream & in, const String & firstline, bool set_opener=true);
-KMPLAYER_EXPORT Node * fromXMLDocumentTag (NodePtr & d, const String & tag);
+KMPLAYER_NO_EXPORT Node * fromXMLDocumentTag (NodePtr & d, const String & tag);
 
 template <class T>
 inline Item<T>::Item () : m_self (static_cast <T*> (this), true) {}
