@@ -384,8 +384,8 @@ void UnixProcess::processExited (GPid pid) {
 
 #define NO_SEEK 0x7fffffff
 
-MPlayer::MPlayer (ProcessNotify * ctrl, bool xv)
- : Process (ctrl, "mplayer", xv),
+MPlayer::MPlayer (ProcessNotify *ctrl, const char *nm)
+ : Process (ctrl, nm, true),
    unix_process (this, UnixProcess::StdIn | UnixProcess::StdOut),
    path ("mplayer"),
    audio_driver (NULL),
@@ -775,621 +775,6 @@ KMPLAYER_NO_EXPORT bool MPlayer::sendCommand (const String & cmd) {
     return false;
 }
 
-//-----------------------------------------------------------------------------
-
-static const char *media_server = "com.nokia.osso_media_server";
-static const char *media_server_path = "/com/nokia/osso_media_server";
-static const char *media_server_imusic = "com.nokia.osso_media_server.music";
-static const char *media_server_ivideo = "com.nokia.osso_media_server.video";
-static const char *media_server_filter = "type='signal',sender='com.nokia.osso_media_server'";
-
-static gboolean cb_stoppedTimer (void * p) {
-    OssoMediaServer * process = static_cast <OssoMediaServer *> (p);
-    process->processStopped ();
-    return 0;
-}
-
-static gboolean cb_retryAudioOnly (void * p) {
-    Process *proc = static_cast <Process *> (p);
-    if (proc->mrl ())
-        proc->play (proc->mrl ());
-    return false; // single shot
-}
-
-/*
-  AddMatch
-  sender=com.nokia.osso_media_server if=com.nokia.soso_media_server.video
-  sender=com.nokia.osso_media_server if=com.nokia.soso_media_server.video.error
-  set_volume if=com.nokia.soso_media_server.video double:1.0
-  signal if=com.nokia.soso_media_server.video mtd=state_changed playing/pauses/stopped/end_of_stream/restart
-  signal if=com.nokia.soso_media_server.video mtd=details_received
-  signal if=com.nokia.soso_media_server.video mtd=info_buffering double:perc
-  signal if=com.nokia.soso_media_server.video mtd=end_buffering double:0.0
-  com.nokia.osso_media_server.sound
-  com.nokia.osso_media_server.music
-  run-standalone.sh dbus-send --dest=com.nokia.osso_media_server --print-reply /com/nokia/osso_media_server com.nokia.osso_media_server.music.play_media string:file:///home/user/MyDocs/.sounds/Everyday.mp3
-*/
-
-static DBusHandlerResult filter_func (DBusConnection * connection,
-        DBusMessage *message, void * user_data) {
-    const char *sender = dbus_message_get_sender (message);
-    int message_type = dbus_message_get_type (message);
-    bool handled = false;
-    OssoMediaServer *process = static_cast <OssoMediaServer *> (user_data);
-
-    if (!process->dbusFilter ())
-        return DBUS_HANDLER_RESULT_HANDLED;
-
-    if (message_type == DBUS_MESSAGE_TYPE_SIGNAL &&
-            !strcmp (dbus_message_get_interface (message),
-                       process->currentMediaServer ())) {
-        DBusMessageIter iter;
-        char *str;
-        dbus_message_iter_init (message, &iter);
-        do {
-            int type = dbus_message_iter_get_arg_type (&iter);
-            const char * method = dbus_message_get_member (message);
-            handled = true;
-            if (!strcmp (method, "info_buffering")) {
-                if (type == DBUS_TYPE_DOUBLE) {
-                    double perc;
-                    dbus_message_iter_get_basic (&iter, &perc);
-                    // printf ("buffering %0.2f\n", perc);
-                    process->processBuffering ((int) perc);
-                } else
-                    printf ("buffering wrong type\n");
-            } else if (!strcmp (method, "begin_buffering")) {
-                printf ("begin_buffering\n");
-                process->processBuffering (0);
-            } else if (!strcmp (method, "end_buffering")) {
-                printf ("end_buffering\n");
-                process->processBuffering (100);
-            } else if (!strcmp (method, "state_changed")) {
-                if (type == DBUS_TYPE_STRING) {
-                    const char * state;
-                    dbus_message_iter_get_basic (&iter, &state);
-                    printf ("state_changed %s\n", state);
-                    if (!strcmp (state, "stopped")) {
-                        if (!process->play_pending && !process->retry ())
-                            process->processStopped ();
-                    } else if (!strcmp (state, "playing"))
-                        process->processPlaying ();
-                    else if (!strcmp (state, "paused"))
-                        process->processPaused ();
-                } else
-                    printf ("state_changed wrong type\n");
-            } else if (!strcmp (method, "end_of_stream")) {
-                printf ("end_of_stream\n");
-                process->processStopped ();
-            } else if (!strcmp (method, "restart")) {
-                printf ("restart\n");
-                process->processStopped ();
-            } else if (!strcmp (method, "iradio_update")) {
-                if (type == DBUS_TYPE_STRING) {
-                    const char * info;
-                    dbus_message_iter_get_basic (&iter, &info);
-                    printf ("iradio_update %s\n", info);
-                    process->infoMessage (String (info) + process->stream_name);
-                } else
-                    printf ("iradio_update %d\n", type);
-            } else if (!strcmp (method, "details_received")) {
-                debugLog() << "details_received " << type << endl;
-                bool aspect_changed = false;
-                if (type == DBUS_TYPE_ARRAY) {
-                    bool eof = false;
-                    DBusMessageIter sub;
-                    dbus_message_iter_recurse (&iter, &sub);
-                    do {
-                        type = dbus_message_iter_get_arg_type (&sub);
-                        if (type == DBUS_TYPE_DICT_ENTRY) {
-                            DBusMessageIter dictsub;
-                            dbus_message_iter_recurse (&sub, &dictsub);
-                            type = dbus_message_iter_get_arg_type (&dictsub);
-                            String key, value;
-                            const char * detail;
-                            if (type == DBUS_TYPE_STRING) {
-                                dbus_message_iter_get_basic (&dictsub, &detail);
-                                key = detail;
-                            }
-                            if (dbus_message_iter_next (&dictsub)) {
-                                type = dbus_message_iter_get_arg_type (&dictsub);
-                                if (type == DBUS_TYPE_STRING) {
-                                    dbus_message_iter_get_basic (&dictsub, &detail);
-                                    value = detail;
-                                }
-                            }
-                            if (!key.isEmpty ()) {
-                                debugLog()<<"detail " <<key << "=" << value << endl;
-                                if (key == "width") {
-                                    process->setWidth (value.toInt ());
-                                    aspect_changed = true;
-                                } else if (key == "height") {
-                                    process->setHeight (value.toInt ());
-                                    aspect_changed = true;
-                                } else if (key == "length") {
-                                    int len = value.toInt () / 100;
-                                    process->setLength (len);
-                                } else if (key == "has_video") {
-                                    int b = value.toInt ();
-                                    process->setHasVideo (!!b);
-                                } else if (key == "name") {
-                                    String s ("<hr><i>");
-                                    s += value;
-                                    s += "</i>";
-                                    process->stream_name = s;
-                                    process->infoMessage (s);
-                                }
-                            }
-                        } else
-                            debugLog() << "details_received sub " << type << endl;
-                        eof = !dbus_message_iter_next (&sub);
-                    } while (!eof);
-                }
-                if (aspect_changed)
-                    g_timeout_add (0, cb_scheduledUpdateAspects, process);
-                //process->updateVideoSize();
-            } else {
-                debugLog() << "Unhandled " << method << endl;
-                handled = false;
-            }
-        } while (dbus_message_iter_next (&iter));
-    } else if (message_type == DBUS_MESSAGE_TYPE_SIGNAL &&
-            !strcmp (dbus_message_get_interface (message),
-                "com.nokia.osso_media_server.video.error")) {
-        const char * method = dbus_message_get_member (message);
-        warningLog() << "Unsupported format " << method << endl;
-        if (!strcmp (method, "unsupported_type")) {
-            if (!process->retry ())
-                process->processStopped ();
-            handled = true;
-        }
-    }
-    if (!handled /*&&
-            strstr (dbus_message_get_interface (message), "osso_media_server")*/)
-        switch (message_type) {
-            case DBUS_MESSAGE_TYPE_INVALID:
-                printf ("invalid message");
-                break;
-            case DBUS_MESSAGE_TYPE_METHOD_CALL:
-                printf ("message interface=%s; member=%s; sender=%s\n",
-                        dbus_message_get_interface (message),
-                        dbus_message_get_member (message),
-                        sender ? sender : "(no sender)");
-                break;
-            case DBUS_MESSAGE_TYPE_SIGNAL:
-                printf ("signal interface=%s; member=%s; sender=%s\n",
-                        dbus_message_get_interface (message),
-                        dbus_message_get_member (message),
-                        sender ? sender : "(no sender)");
-                break;
-            case DBUS_MESSAGE_TYPE_METHOD_RETURN:
-                //printf ("message return");
-                break;
-            case DBUS_MESSAGE_TYPE_ERROR: {
-                DBusError err;
-                dbus_error_init(&err);
-                if (err.message) {
-                    printf ("message error: %s\n", err.message);
-                    process->processStopped ();
-                }
-                break;
-            }
-            default:
-                printf ("filter_func unknown\n");
-        }
-    //print_message (message);
-
-    if (dbus_message_is_signal (message,
-                DBUS_INTERFACE_LOCAL,
-                "Disconnected"))
-        ;//exit (0);
-
-    /* Conceptually we want this to be
-     * DBUS_HANDLER_RESULT_NOT_YET_HANDLED, but this raises
-     * some problems.  See bug 1719.
-     */
-    return DBUS_HANDLER_RESULT_HANDLED;
-}
-
-static void cb_playMedia (DBusPendingCall * pending, void * user_data) {
-    OssoMediaServer * process = static_cast <OssoMediaServer *> (user_data);
-    DBusMessage *reply = dbus_pending_call_steal_reply (pending);
-    if (reply) {
-        int type = dbus_message_get_type (reply);
-        if (type == DBUS_MESSAGE_TYPE_ERROR) {
-            DBusError error;
-            dbus_error_init (&error);
-            dbus_set_error_from_message (&error, reply);
-            errorLog () << error.name << ": " << error.message << endl;
-            process->processNotify ()->errorMsg (error.message);
-            if (process->state () > Process::Ready)
-                process->setState (Process::Ready);
-            dbus_error_free (&error);
-        }
-        dbus_message_unref (reply);
-    }
-    process->play_pending = 0L;
-}
-
-static void cb_posMedia (DBusPendingCall * pending, void * user_data) {
-    OssoMediaServer * process = static_cast <OssoMediaServer *> (user_data);
-    DBusMessage *reply = dbus_pending_call_steal_reply (pending);
-    if (reply) {
-        int type = dbus_message_get_type (reply);
-        if (type == DBUS_MESSAGE_TYPE_METHOD_RETURN) {
-            DBusMessageIter iter;
-            dbus_message_iter_init (reply, &iter);
-            type = dbus_message_iter_get_arg_type (&iter);
-            if (type == DBUS_TYPE_INT32) {
-                int pos;
-                dbus_message_iter_get_basic (&iter, &pos);
-                if (dbus_message_iter_next (&iter)) {
-                    type = dbus_message_iter_get_arg_type (&iter);
-                    if (type == DBUS_TYPE_INT32) {
-                        int len;
-                        dbus_message_iter_get_basic (&iter, &len);
-                        process->setLength (len/100);
-                    }
-                }
-                process->setPosition (pos/100);
-            }
-        }
-        dbus_message_unref (reply);
-    }
-    process->pos_pending = 0L;
-}
-
-static void cb_seekMedia (DBusPendingCall * pending, void * user_data) {
-    OssoMediaServer * process = static_cast <OssoMediaServer *> (user_data);
-    DBusMessage *reply = dbus_pending_call_steal_reply (pending);
-    if (reply)
-        dbus_message_unref (reply);
-    process->seek_pending = 0L;
-}
-
-static gboolean cb_getPosition (void * p) {
-    OssoMediaServer * proc = static_cast <OssoMediaServer *> (p);
-    if (!proc->seek_pending && !proc->pos_pending) {
-        DBusConnection * con = (DBusConnection *)osso_get_dbus_connection (
-                proc->ossoContext ());
-        DBusMessage *msg = dbus_message_new_method_call (0L,
-                media_server_path,
-                proc->currentMediaServer (),
-                "get_position");
-        dbus_message_set_destination (msg, media_server);
-        if (dbus_connection_send_with_reply(con, msg, &proc->pos_pending, 5000))
-            dbus_pending_call_set_notify (proc->pos_pending, cb_posMedia, p, 0);
-        dbus_message_unref (msg);
-    }
-    return true; // repeat
-}
-
-const char * OssoMediaServer::myname = "osso-media-server";
-
-KMPLAYER_NO_CDTOR_EXPORT
-OssoMediaServer::OssoMediaServer (ProcessNotify * ctrl, osso_context_t * ctx, bool xv)
-    : Process (ctrl, myname, xv),
-      play_pending (0L), pos_pending (0L), seek_pending (0L),
-      m_osso_context (ctx),
-      m_volume (0.3),
-      current_service (""),
-      dbus_filter (NULL),
-      have_played (false),
-      try_audio_only (false),
-      first_time (true),
-      retry_timer (0), pos_timer (0) {
-}
-
-KDE_NO_CDTOR_EXPORT OssoMediaServer::~OssoMediaServer () {
-    if (have_played)
-        setVideoWindow (200, 60, 560, 380); // something sane
-    if (!first_time) {
-        DBusConnection *conn = (DBusConnection *)osso_get_dbus_connection (m_osso_context);
-        if (conn)
-            dbus_connection_remove_filter (conn, filter_func, this);
-    }
-}
-
-KMPLAYER_NO_EXPORT bool OssoMediaServer::stop () {
-    if (play_pending) {
-        dbus_pending_call_cancel (play_pending);
-        play_pending = 0L;
-    }
-    if (pos_pending) {
-        dbus_pending_call_cancel (pos_pending);
-        pos_pending = 0L;
-    }
-    if (seek_pending) {
-        dbus_pending_call_cancel (seek_pending);
-        seek_pending = 0L;
-    }
-    try_audio_only = false;
-    if (retry_timer) {
-        g_source_remove (retry_timer);
-        retry_timer = 0;
-    }
-    if (pos_timer) {
-        g_source_remove (pos_timer);
-        pos_timer = 0;
-    }
-    if (!playing ()) return true;
-    DBusConnection * connection = (DBusConnection *)osso_get_dbus_connection (m_osso_context);
-    DBusMessage *message = dbus_message_new_method_call (media_server, media_server_path, current_service, "stop");
-    DBusMessage *reply;
-    DBusError error;
-    dbus_error_init (&error);
-    reply = dbus_connection_send_with_reply_and_block (connection,
-            message, 500, &error);
-    if (!reply) {
-        errorLog() << "stop error: " << error.message << endl;
-        dbus_error_free (&error);
-    } else
-        dbus_message_unref (reply);
-    //dbus_connection_send (connection, message, NULL);
-    dbus_connection_flush (connection);
-    dbus_message_unref (message);
-    // m_state will be set back to Ready via dbus callback ..
-    return true;
-}
-
-KMPLAYER_NO_EXPORT bool OssoMediaServer::quit () {
-    if (m_state > NotRunning) {
-        if (playing ()) {
-            stop ();
-        }
-    }
-    setState (NotRunning);
-    return !playing ();
-}
-
-KMPLAYER_NO_EXPORT bool OssoMediaServer::ready (unsigned int viewer) {
-    if (m_state < Ready)
-        return Process::ready (viewer);
-    return false;
-}
-
-KMPLAYER_NO_EXPORT bool OssoMediaServer::retry () {
-    if (have_played_stream ||
-            !current_service ||
-            !strcmp (current_service, media_server_imusic)) {
-        return false;
-    } else if (retry_timer) {
-        return true;
-    } else if (m_mrl && !mrl ()->audio_only && mrl ()->media_info) {
-        try_audio_only = true;
-        retry_timer = g_timeout_add (100, cb_retryAudioOnly, this);
-        return true;
-    }
-    return false;
-}
-
-KMPLAYER_NO_EXPORT void OssoMediaServer::updateVideoSize () {
-    //debugLog () <<  "OssoMediaServer::updateVideoWindow " << (!m_mrl) << " " <<  (has_xv && !m_viewer) << " " << (!has_xv && m_rect == m_cur_rect) << endl;
-    if (!m_mrl || (has_xv && !m_viewer)  /*hasVideo () */ ||
-            (!has_xv && m_rect == m_cur_rect))
-        return;
-    DBusConnection * connection = (DBusConnection *)osso_get_dbus_connection (m_osso_context);
-    DBusMessage *message = dbus_message_new_method_call (media_server, media_server_path, media_server_ivideo, "set_video_window");
-    dbus_message_set_auto_start (message, true);
-    if (has_xv) {
-        unsigned x = m_viewer;
-        unsigned y = 0;
-        unsigned w = 0;
-        unsigned h = 0;
-        debugLog () << "OssoMediaServer::updateVideoWindow " << m_viewer <<endl;
-        dbus_message_append_args (message, DBUS_TYPE_UINT32, &x, DBUS_TYPE_UINT32, &y, DBUS_TYPE_UINT32, &w, DBUS_TYPE_UINT32, &h, DBUS_TYPE_INVALID);
-    } else {
-        int x = m_rect.x();
-        int y = m_rect.y();
-        int w = m_rect.width();
-        int h = m_rect.height();
-        debugLog () <<  "OssoMediaServer::updateVideoWindow " << x << ", " << y
-            << " " << w << "x" << h << endl;
-        dbus_message_append_args (message, DBUS_TYPE_INT32, &x, DBUS_TYPE_INT32, &y,
-                DBUS_TYPE_INT32, &w, DBUS_TYPE_INT32, &h, DBUS_TYPE_INVALID);
-    }
-    dbus_connection_send (connection, message, NULL);
-    dbus_connection_flush (connection);
-    dbus_message_unref (message);
-    m_cur_rect = m_rect;
-}
-
-KMPLAYER_NO_EXPORT bool OssoMediaServer::play (NodePtr node) {
-    //debugLog() << "OssoMediaServer::play " << m_viewer << endl;
-    if (retry_timer) // are we called by the retry timer
-        retry_timer = 0;
-    else
-        try_audio_only = false;
-    Process::play (node);
-    stream_name.clear ();
-    if (m_url.isEmpty ()) {
-        return false;
-    }
-    URL url (m_url);
-    is_local_file = url.isLocalFile ();
-    have_played_stream = false;
-    DBusConnection * connection = (DBusConnection *)osso_get_dbus_connection (m_osso_context);
-    if (m_state < Buffering) {
-        have_played = true;
-        updateVideoSize ();
-        if (!dbus_filter) {
-            DBusError err;
-            dbus_error_init (&err);
-            dbus_filter = media_server_filter;
-            dbus_bus_add_match (connection, dbus_filter, &err);
-            if (dbus_error_is_set (&err)) {
-                errorLog () << "add match error: " << err.message << endl;
-                dbus_error_free (&err);
-            }
-        }
-        if (first_time) {
-            dbus_connection_add_filter (connection, filter_func, this, NULL);
-            first_time = false;
-        }
-    }
-    volume (0, false);
-    no_video = mrl ()->audio_only || try_audio_only;
-    current_service = no_video
-        ? media_server_imusic
-        : media_server_ivideo;
-    DBusMessage *msg = dbus_message_new_method_call (0L, media_server_path, current_service, "play_media");
-    dbus_message_set_destination (msg, media_server);
-    const char * path = (const char *) m_url;
-    debugLog () << "OssoMediaServer::play " << current_service << " " << path << endl;
-    dbus_message_append_args(msg, DBUS_TYPE_STRING,&path,DBUS_TYPE_INVALID);
-    //dbus_connection_send (connection, message, NULL);
-    //dbus_connection_flush (connection);
-
-    // first set to Buffering, as we might get an error signal before returning
-    if (m_state < Buffering)
-        setState (Buffering); // TODO: add timeout 
-
-    if (dbus_connection_send_with_reply (connection,
-                msg, &play_pending, 5000))
-        dbus_pending_call_set_notify (play_pending,cb_playMedia,(void*)this,0L);
-    else
-        setState (Ready);
-    dbus_message_unref (msg);
-    return m_state == Buffering;
-}
-
-KMPLAYER_NO_EXPORT bool OssoMediaServer::pause () {
-    //debugLog() << "OssoMediaServer::pause" << endl;
-    if (m_state > Ready) {
-        if (!has_xv)
-            updateVideoSize ();
-        dbusSend ((DBusConnection *)osso_get_dbus_connection (ossoContext ()),
-                media_server, media_server_path, media_server_ivideo,
-                "pause", DBUS_TYPE_INVALID);
-    }
-}
-
-KMPLAYER_NO_EXPORT bool OssoMediaServer::seek (int pos, bool absolute) {
-    if (seek_pending || pos_pending || !playing ())
-        return false;
-    pos *= 100;
-    DBusConnection * con = (DBusConnection *)osso_get_dbus_connection (
-            ossoContext ());
-    DBusMessage *msg = dbus_message_new_method_call (0L,
-            media_server_path, currentMediaServer (), "seek");
-    dbus_message_set_destination (msg, media_server);
-    int abs = absolute ? 1 : 0;
-    dbus_message_append_args (msg, DBUS_TYPE_INT32, &abs,
-            DBUS_TYPE_INT32, &pos, DBUS_TYPE_INVALID);
-    if (dbus_connection_send_with_reply (con, msg, &seek_pending, 5000))
-        dbus_pending_call_set_notify (seek_pending,cb_seekMedia,(void*)this,0L);
-    dbus_message_unref (msg);
-    return true;
-}
-
-KMPLAYER_NO_EXPORT bool OssoMediaServer::volume (int incdec, bool absolute) {
-    m_volume += 1.0 * incdec / 40;
-    if (m_volume < 0.0)
-        m_volume = 0.0;
-    else if (m_volume > 1.0)
-        m_volume = 1.0;
-
-    DBusConnection *conn = (DBusConnection *)osso_get_dbus_connection (
-                            ossoContext ());
-    dbusSend (conn, media_server, media_server_path, media_server_imusic,
-            "set_volume",
-            DBUS_TYPE_DOUBLE, &m_volume, DBUS_TYPE_INVALID);
-    dbusSend (conn, media_server, media_server_path, media_server_ivideo,
-            "set_volume",
-            DBUS_TYPE_DOUBLE, &m_volume, DBUS_TYPE_INVALID);
-}
-
-KMPLAYER_NO_EXPORT bool OssoMediaServer::saturation (int val, bool absolute) {
-}
-
-KMPLAYER_NO_EXPORT bool OssoMediaServer::hue (int val, bool absolute) {
-}
-
-KMPLAYER_NO_EXPORT bool OssoMediaServer::contrast (int val, bool /*absolute*/) {
-}
-
-KMPLAYER_NO_EXPORT bool OssoMediaServer::brightness (int val, bool /*absolute*/) {
-}
-
-KMPLAYER_NO_EXPORT
-void OssoMediaServer::setVideoWindow (int x, int y, int w, int h) {
-    //debugLog() << "OssoMediaServer::setVideoWindow " << w << "x" << h << endl;
-    if (!(x < 0 || y < 0 || w <= 0 || h <= 1 /* hack !!*/ ||
-                x > 800 || y > 480 || w > 800 || h > 480))
-        m_rect = IRect (x, y, w, h);
-}
-
-KMPLAYER_NO_EXPORT void OssoMediaServer::processStopped () {
-    if (dbus_filter) {
-        DBusError err;
-        dbus_error_init (&err);
-        DBusConnection * conn = (DBusConnection *)osso_get_dbus_connection (m_osso_context);
-        dbus_bus_remove_match (conn, dbus_filter, &err);
-        if (dbus_error_is_set (&err)) {
-            errorLog () << "remove match error: " << err.message << endl;
-            dbus_error_free (&err);
-        }
-        dbus_filter = NULL;
-    }
-    if (retry_timer) {
-        g_source_remove (retry_timer);
-        retry_timer = 0;
-        try_audio_only = true;
-    }
-    if (m_state > Ready)
-        setState (Ready);
-}
-
-KMPLAYER_NO_EXPORT void OssoMediaServer::processBuffering (int perc) {
-    if (perc < 100)
-        setState (Buffering);
-    m_notify->setLoading (perc);
-}
-
-KMPLAYER_NO_EXPORT void OssoMediaServer::processPlaying () {
-    setState (Playing);
-    have_played_stream = true;
-    if (!pos_timer)
-        pos_timer = g_timeout_add (5000, cb_getPosition, this);
-    Mrl *m = mrl ();
-    if (is_local_file && m && m->clip_begin > 100)
-        seek (m->clip_begin/10, true);
-}
-
-KMPLAYER_NO_EXPORT void OssoMediaServer::processPaused () {
-    if (m_state == Paused) // ugh
-        pause ();
-    else
-        setState (Paused);
-}
-
-KMPLAYER_NO_EXPORT void OssoMediaServer::setLength (int l) {
-    if (l != m_length) {
-        m_length = l;
-        m_notify->setLength (l);
-    }
-}
-
-/*void OssoMediaServer::setAudioLang (int id, const QString &) {
-    SharedPtr <LangInfo> li = alanglist;
-    for (; id > 0 && li; li = li->next)
-        id--;
-    if (li)
-        aid = li->id;
-    m_needs_restarted = true;
-    sendCommand (QString ("quit"));
-}
-
-void OssoMediaServer::setSubtitle (int id, const QString &) {
-    SharedPtr <LangInfo> li = slanglist;
-    for (; id > 0 && li; li = li->next)
-        id--;
-    if (li)
-        sid = li->id;
-    m_needs_restarted = true;
-    sendCommand (QString ("quit"));
-}*/
-
 #ifdef __ARMEL__
 
 static NSNotify ns_notify;
