@@ -25,13 +25,7 @@
 #include <stdio.h>
 
 #include <gtk/gtkmain.h>
-#include <libgnomevfs/gnome-vfs-ops.h>
-#include <libgnomevfs/gnome-vfs-async-ops.h>
-#include <libgnomevfs/gnome-vfs-uri.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
-#include <libgnomevfs/gnome-vfs-mime-utils.h>
-#include <libgnomevfs/gnome-vfs-module-callback.h>
-#include <libgnomevfs/gnome-vfs-standard-callbacks.h>
+#include <gio/gio.h>
 
 #include "kmplayertypes.h"
 
@@ -436,39 +430,43 @@ void GLibString::truncate (int pos) {
 
 namespace KMPlayer {
 
-class GnomeVFSFilePrivate {
+class GIOFilePrivate {
 public:
-    GnomeVFSFilePrivate () : m_vfshandle (0L) {}
-    ~GnomeVFSFilePrivate () {}
-    GnomeVFSHandle * m_vfshandle;
+    GIOFilePrivate () : file (NULL), fin (NULL), fout (NULL) {}
+    ~GIOFilePrivate () {}
+    GFile *file;
+    GInputStream *fin;
+    GOutputStream *fout;
     String m_path;
 };
 
 }
 
 KMPLAYER_NO_CDTOR_EXPORT
-GnomeVFSFile::GnomeVFSFile (const String & p) : d (new GnomeVFSFilePrivate) {
+GIOFile::GIOFile (const String & p) : d (new GIOFilePrivate) {
     d->m_path = p;
+    d->file = g_file_new_for_path ((const char *) d->m_path);
 }
 
-KMPLAYER_NO_CDTOR_EXPORT GnomeVFSFile::~GnomeVFSFile () {
+KMPLAYER_NO_CDTOR_EXPORT GIOFile::~GIOFile () {
     close ();
+    g_object_unref (G_OBJECT (d->file));
+    d->file = NULL;
     delete d;
 }
 
-KMPLAYER_NO_EXPORT bool GnomeVFSFile::open (FileMode mode) {
+KMPLAYER_NO_EXPORT bool GIOFile::open (FileMode mode) {
     switch (mode) {
         case IO_ReadOnly:
-            if (gnome_vfs_open (&d->m_vfshandle, (const char *) d->m_path, GNOME_VFS_OPEN_READ) == GNOME_VFS_OK)
+            d->fin = G_INPUT_STREAM (g_file_read (d->file, NULL, NULL));
+            if (d->fin)
                 return true;
-            d->m_vfshandle = 0L;
             break;
         case IO_WriteOnly: // fixme truncate
-            if (gnome_vfs_open (&d->m_vfshandle, (const char *) d->m_path, GNOME_VFS_OPEN_WRITE) == GNOME_VFS_OK)
+            d->fout = G_OUTPUT_STREAM (g_file_replace (d->file, NULL, false,
+                    G_FILE_CREATE_NONE, NULL, NULL));
+            if (d->fout)
                 return true;
-            if (gnome_vfs_create (&d->m_vfshandle,(const char *) d->m_path, GNOME_VFS_OPEN_WRITE, TRUE, GNOME_VFS_PERM_USER_ALL) == GNOME_VFS_OK)
-                return true;
-            d->m_vfshandle = 0L;
             break;
         default:
             warningLog() << "open " << int (mode) << " not implemented" << endl;
@@ -476,154 +474,179 @@ KMPLAYER_NO_EXPORT bool GnomeVFSFile::open (FileMode mode) {
     return false;
 }
 
-KMPLAYER_NO_EXPORT void GnomeVFSFile::close () {
-    if (d->m_vfshandle) {
-        gnome_vfs_close (d->m_vfshandle);
-        d->m_vfshandle = 0L;
+KMPLAYER_NO_EXPORT void GIOFile::close () {
+    if (d->fin) {
+        g_object_unref (G_OBJECT (d->fin));
+        d->fin = NULL;
+    }
+    if (d->fout) {
+        g_object_unref (G_OBJECT (d->fout));
+        d->fout = NULL;
     }
 }
 
-KMPLAYER_NO_EXPORT ByteArray GnomeVFSFile::readAll () {
+KMPLAYER_NO_EXPORT ByteArray GIOFile::readAll () {
     ByteArray str;
     char buf [2048];
-    GnomeVFSFileSize nr;
-    if (!d->m_vfshandle && !open (IO_ReadOnly))
+    gsize nr;
+    if (d->fin)
+        close (); // seek 0
+    if (!open (IO_ReadOnly))
         return str;
-    gnome_vfs_seek (d->m_vfshandle, GNOME_VFS_SEEK_START, 0);
     do {
-        if (gnome_vfs_read (d->m_vfshandle, buf, sizeof (buf) -1, &nr) != GNOME_VFS_OK)
+        nr = g_input_stream_read (d->fin, buf, sizeof (buf), NULL, NULL);
+        if (nr <= 0)
             break;
         off_t size = str.size ();
         str.resize (size + nr);
         memcpy (str.data () + size, buf, nr);
-    } while (nr > 0);
+    } while (true);
     return str;
 }
 
-KMPLAYER_NO_EXPORT off_t GnomeVFSFile::readBlock (char * buf, off_t max) {
-    if (!d->m_vfshandle && !open (IO_ReadOnly))
+KMPLAYER_NO_EXPORT off_t GIOFile::readBlock (char * buf, off_t max) {
+    if (!d->fin && !open (IO_ReadOnly))
         return 0;
-    GnomeVFSFileSize nr;
-    if (gnome_vfs_read (d->m_vfshandle, buf, max, &nr) != GNOME_VFS_OK)
-        return 0;
-    return nr;
+    gsize nr = g_input_stream_read (d->fin, buf, max, NULL, NULL);
+    return nr < 0 ? 0 : nr;
 }
 
-KMPLAYER_NO_EXPORT bool GnomeVFSFile::exists () {
-    GnomeVFSFileInfo info;
-    return (gnome_vfs_get_file_info ((const char *) d->m_path, &info, GNOME_VFS_FILE_INFO_DEFAULT) == GNOME_VFS_OK);
+KMPLAYER_NO_EXPORT bool GIOFile::exists () {
+    return g_file_query_exists (d->file, NULL);
 }
 
-KMPLAYER_NO_EXPORT off_t GnomeVFSFile::size () {
-    GnomeVFSFileInfo info;
-    if (gnome_vfs_get_file_info ((const char *) d->m_path, &info, GNOME_VFS_FILE_INFO_DEFAULT) != GNOME_VFS_OK)
-        return 0;
-    return info.size;
-}
-
-KMPLAYER_NO_EXPORT off_t GnomeVFSFile::writeBlock (const char * data, off_t length) {
-    off_t len = length;
-    while (len > 0) {
-        GnomeVFSFileSize bytes_written;
-        if (gnome_vfs_write (d->m_vfshandle, data + (length - len), len, &bytes_written) != GNOME_VFS_OK)
-            break;
-        len -= bytes_written;
+KMPLAYER_NO_EXPORT off_t GIOFile::size () {
+    goffset sz = 0;
+    GFileInfo *info = g_file_query_info (d->file,
+            G_FILE_ATTRIBUTE_STANDARD_SIZE,
+            G_FILE_QUERY_INFO_NONE, NULL, NULL);
+    if (info) {
+        sz = g_file_info_get_size (info);
+        g_object_unref (info);
     }
-    return length - len;
+    return sz;
+}
+
+KMPLAYER_NO_EXPORT off_t GIOFile::writeBlock (const char * data, off_t length) {
+    gsize nr;
+    g_output_stream_write_all (d->fout, data, length, &nr, NULL, NULL);
+    return nr;
 }
 
 //-----------------------------------------------------------------------------
 
-GnomeVFSUrl::GnomeVFSUrl (const GnomeVFSUrl & base, const String & rel) {
-    m_vfsurl= (base.m_vfsurl ?
-            gnome_vfs_uri_resolve_relative (base.m_vfsurl, rel) :
-            gnome_vfs_uri_new ((const char *) rel));
+GioUrl::GioUrl (const GioUrl &base, const String &rel) {
+    if (base.m_file) {
+        GFile *p = g_file_get_parent (base.m_file);
+        m_file = g_file_resolve_relative_path (p ? p : base.m_file, rel);
+        if (p)
+            g_object_unref (p);
+    } else {
+        m_file = g_file_new_for_uri ((const char *) rel);
+    }
 }
 
-KMPLAYER_NO_CDTOR_EXPORT GnomeVFSUrl::GnomeVFSUrl (const String & url) {
-    m_vfsurl = (url.isEmpty () ? 0L : gnome_vfs_uri_new ((const char *) url));
+KMPLAYER_NO_CDTOR_EXPORT GioUrl::GioUrl (const String &url) : m_file (NULL) {
+    if (url.startsWith (Char ('/')))
+        m_file = g_file_new_for_path (url);
+    else if (!url.isEmpty ())
+        m_file = g_file_new_for_uri ((const char *) url);
 }
 
-KMPLAYER_NO_CDTOR_EXPORT GnomeVFSUrl::GnomeVFSUrl (const GnomeVFSUrl & url) {
-    m_vfsurl = (url.m_vfsurl ? gnome_vfs_uri_dup (url.m_vfsurl) : 0L);
+GioUrl::GioUrl (const File &file)
+{
+    m_file = g_file_dup (file.d->file);
 }
 
-KMPLAYER_NO_CDTOR_EXPORT GnomeVFSUrl::~GnomeVFSUrl () {
-    if (m_vfsurl)
-        gnome_vfs_uri_unref (m_vfsurl);
+KMPLAYER_NO_CDTOR_EXPORT GioUrl::GioUrl (const GioUrl & url) {
+    m_file = (url.m_file ? g_file_dup (url.m_file) : 0L);
 }
 
-KMPLAYER_NO_EXPORT String GnomeVFSUrl::url () const {
-    if (m_vfsurl) {
+KMPLAYER_NO_CDTOR_EXPORT GioUrl::~GioUrl () {
+    if (m_file)
+        g_object_unref (m_file);
+}
+
+KMPLAYER_NO_EXPORT String GioUrl::url () const {
+    if (m_file) {
         GLibString s;
-        s.take (gnome_vfs_uri_to_string (m_vfsurl, GNOME_VFS_URI_HIDE_NONE));
+        s.take (g_file_get_uri (m_file));
         return String (s);
     }
     return String ();
 }
 
-GnomeVFSUrl & GnomeVFSUrl::operator = (const String & url) {
-    if (m_vfsurl)
-        gnome_vfs_uri_unref (m_vfsurl);
-    m_vfsurl = gnome_vfs_uri_new ((const char *) url);
+GioUrl & GioUrl::operator = (const String &url) {
+    if (m_file)
+        g_object_unref (m_file);
+    m_file = g_file_new_for_uri ((const char *) url);
     return *this;
 }
 
-GnomeVFSUrl & GnomeVFSUrl::operator = (const GnomeVFSUrl & url) {
-    if (m_vfsurl)
-        gnome_vfs_uri_unref (m_vfsurl);
-    m_vfsurl = url.m_vfsurl ? gnome_vfs_uri_dup (url.m_vfsurl) : 0L;
+GioUrl & GioUrl::operator = (const GioUrl & url) {
+    if (m_file)
+        g_object_unref (m_file);
+    m_file = url.m_file ? g_file_dup (url.m_file) : 0L;
     return *this;
 }
 
-KMPLAYER_NO_EXPORT String GnomeVFSUrl::path () const {
-    if (m_vfsurl)
-        return String (gnome_vfs_uri_get_path (m_vfsurl));
+KMPLAYER_NO_EXPORT String GioUrl::path () const {
+    if (m_file)
+        return String (g_file_get_path (m_file));
     return String ();
 }
 
-KMPLAYER_NO_EXPORT String GnomeVFSUrl::protocol () const {
-    if (m_vfsurl)
-        return String (gnome_vfs_uri_get_scheme (m_vfsurl));
+KMPLAYER_NO_EXPORT String GioUrl::protocol () const {
+    if (m_file)
+        return String (g_file_get_uri_scheme (m_file));
     return String ();
 }
 
-KMPLAYER_NO_EXPORT String GnomeVFSUrl::decode_string (const String & s) {
+KMPLAYER_NO_EXPORT String GioUrl::decode_string (const String & s) {
     if (s.isEmpty ())
         return String ();
     String str;
     GLibString &gs = str;
-    gs.take(gnome_vfs_unescape_string ((const char *) s, ""));
+    gs.take (g_uri_unescape_string ((const char *) s, ""));
     return str;
 }
 
-KMPLAYER_NO_EXPORT String GnomeVFSUrl::encode_string (const String & s) {
+KMPLAYER_NO_EXPORT String GioUrl::encode_string (const String & s) {
     if (s.isEmpty ())
         return String ();
     String str;
     GLibString &gs = str;
-    gs.take(gnome_vfs_escape_string ((const char *) s));
+    gs.take(g_uri_escape_string ((const char *) s, "", TRUE));
     return str;
 }
 
-KMPLAYER_NO_EXPORT bool GnomeVFSUrl::isLocalFile () const {
-    if (m_vfsurl)
-        return gnome_vfs_uri_is_local (m_vfsurl) ||
+KMPLAYER_NO_EXPORT bool GioUrl::isLocalFile () const {
+    if (m_file)
+        return g_file_is_native (m_file) ||
             protocol () == "file";
     return false;
 }
 
 //-----------------------------------------------------------------------------
 
-String GMimeType::findByContent (const char * data, int size) {
-    if (size <= 0)
+String GMimeType::findByContent (const char *data, int nr) {
+    if (nr <= 0)
         return String();
     const gchar *end;
-    if (g_utf8_validate ((gchar *) data, size, &end))
+    if (g_utf8_validate ((gchar *) data, nr, &end))
         return "text/plain";
-    if (g_utf8_get_char_validated (end, size - (end - data)) == (gunichar)-2)
+    if (g_utf8_get_char_validated (end, nr - (end - data)) == (gunichar)-2)
         return "text/plain";
-    return String (gnome_vfs_get_mime_type_for_data (data, size));
+    gboolean pb;
+    return String (g_content_type_guess (NULL, (const guchar *)data, nr, &pb));
+}
+
+String GMimeType::findByURL (const URL &url) {
+    gboolean pb;
+    if (url.isLocalFile ())
+        return String (g_content_type_guess (url.path (), NULL, 200, &pb));
+    warningLog () << "GMimeType::findByURL not supported on remote links\n";
+    return String ();
 }
 
 //-----------------------------------------------------------------------------
@@ -1148,6 +1171,7 @@ void CurlGetJob::init (IOJob *job) {
     //curl_easy_setopt (easy, CURLOPT_SHARE, m_curlShareHandle);
     //curl_share_setopt(share_handle,CURL_LOCK_DATA_DNS);
     //curl_share_cleanup(CURLSH * share_handle );
+    curl_easy_setopt (easy, CURLOPT_IPRESOLVE, CURL_IPRESOLVE_V4);
     curl_easy_setopt (easy, CURLOPT_DNS_CACHE_TIMEOUT, 60 * 5);
     curl_easy_setopt (easy, CURLOPT_ENCODING, "");
     curl_easy_setopt (easy, CURLOPT_USERAGENT, "KMPlayer/" VERSION);
