@@ -29,7 +29,8 @@
 #include <glib.h>
 #include <gdk/gdk.h>
 #include <gconf/gconf-client.h>
-#include <libgnomevfs/gnome-vfs-mime-utils.h>
+
+typedef struct _GFile GFILE;
 
 #undef KDE_NO_CDTOR_EXPORT
 #undef KDE_NO_EXPORT
@@ -58,11 +59,9 @@
 //#define ASSERT Q_ASSERT
 #endif
 
-struct GnomeVFSURI;
-
 namespace KMPlayer {
 
-class GnomeVFSFilePrivate;
+class GIOFilePrivate;
 
 /**
  * Type meant for screen coordinates
@@ -338,11 +337,12 @@ typedef GLibString String;
 
 enum FileMode { IO_ReadOnly=0x01, IO_WriteOnly=0x02, IO_ReadWrite=0x03 };
 
-class GnomeVFSFile {
-    GnomeVFSFilePrivate * d;
+class GIOFile {
+    GIOFilePrivate * d;
+    friend class GioUrl;
 public:
-    GnomeVFSFile (const String & path);
-    ~GnomeVFSFile ();
+    GIOFile (const String & path);
+    ~GIOFile ();
     bool open (FileMode mode);
     void close ();
     ByteArray readAll ();
@@ -352,7 +352,7 @@ public:
     off_t size ();
 };
 
-typedef GnomeVFSFile File;
+typedef GIOFile File;
 
 
 class GLibTextStream {
@@ -383,26 +383,27 @@ private:
 typedef GLibTextStream TextStream;
 
 
-class GnomeVFSUrl {
-    GnomeVFSURI * m_vfsurl;
+class GioUrl {
+    GFile *m_file;
 public:
-    GnomeVFSUrl ();
-    GnomeVFSUrl (const String & ur);
-    GnomeVFSUrl (const GnomeVFSUrl & base, const String & rel);
-    GnomeVFSUrl (const GnomeVFSUrl & url);
-    ~GnomeVFSUrl ();
-    GnomeVFSUrl & operator = (const String & url);
-    GnomeVFSUrl & operator = (const GnomeVFSUrl & url);
-    bool operator == (const GnomeVFSUrl &u) const { return url() == u.url(); }
+    GioUrl ();
+    GioUrl (const String &url);
+    GioUrl (const File &file);
+    GioUrl (const GioUrl &base, const String &rel);
+    GioUrl (const GioUrl &url);
+    ~GioUrl ();
+    GioUrl & operator = (const String &url);
+    GioUrl & operator = (const GioUrl &url);
+    bool operator == (const GioUrl &u) const { return url() == u.url(); }
     String url () const;
     String path () const;
     String protocol () const;
-    static String decode_string (const String & str);
-    static String encode_string (const String & str);
+    static String decode_string (const String &str);
+    static String encode_string (const String &str);
     bool isLocalFile () const;
 };
 
-typedef GnomeVFSUrl URL;
+typedef GioUrl URL;
 
 
 class GMimeType {
@@ -1161,13 +1162,7 @@ KMPLAYER_NO_EXPORT inline const gchar *GLibTextStream::at () const {
 
 //-----------------------------------------------------------------------------
 
-KMPLAYER_NO_CDTOR_EXPORT inline GnomeVFSUrl::GnomeVFSUrl () : m_vfsurl (0L) {}
-
-//-----------------------------------------------------------------------------
-
-inline String GMimeType::findByURL (const URL & url) {
-    return String (gnome_vfs_get_mime_type ((const char *) url.url ()));
-}
+KMPLAYER_NO_CDTOR_EXPORT inline GioUrl::GioUrl () : m_file (0L) {}
 
 //-----------------------------------------------------------------------------
 
