@@ -67,9 +67,11 @@ typedef struct _StreamInfo {
     unsigned int stream_pos;
     unsigned int total;
     unsigned int reason;
+    unsigned int post_len;
     char *url;
     char *mimetype;
     char *target;
+    char *post;
     bool notify;
     bool called_plugin;
     bool destroyed;
@@ -113,13 +115,16 @@ static void freeStream (StreamInfo *si) {
         g_free (si->mimetype);
     if (si->target)
         g_free (si->target);
+    if (si->post)
+        g_free (si->post);
     nsMemFree (si);
 }
 
 static gboolean requestStream (void * p) {
     StreamInfo *si = (StreamInfo *) g_tree_lookup (stream_list, p);
     if (si) {
-        browser_notify->getUrl (npp, (int)(long)p, si->url, si->target, browser_data);
+        browser_notify->getUrl (npp, (int)(long)p, si->url, si->target,
+                si->post_len, si->post, browser_data);
     } else {
         print ("requestStream %d not found", (long) p);
     }
@@ -186,7 +191,9 @@ static int32_t writeStream (uint32_t stream, const char *buf, uint32_t count) {
     return sz;
 }
 
-static StreamInfo *addStream (const char *url, const char *mime, const char *target, void *notify_data, bool notify) {
+static StreamInfo *addStream (const char *url, const char *mime,
+        const char *target, int len, const char *post, void *notify_data,
+        bool notify) {
     StreamInfo *si = (StreamInfo *) nsAlloc (sizeof (StreamInfo));
 
     memset (si, 0, sizeof (StreamInfo));
@@ -196,6 +203,11 @@ static StreamInfo *addStream (const char *url, const char *mime, const char *tar
         si->mimetype = g_strdup (mime);
     if (target)
         si->target = g_strdup (target);
+    if (len && post) {
+        si->post_len = len;
+        si->post = (char *) nsAlloc (len);
+        memcpy (si->post, post, len);
+    }
     si->np_stream.notifyData = notify_data;
     si->notify = notify;
     si->np_stream.ndata = (void *) (long) (stream_id_counter++);
@@ -304,15 +316,15 @@ static void nsReleaseObject (NPObject *npobj) {
 static NPError nsGetURL (NPP instance, const char* url, const char* target) {
     (void)instance;
     print ("nsGetURL %s %s\n", url, target);
-    addStream (url, 0L, target, 0L, false);
+    addStream (url, 0L, target, 0, NULL, 0L, false);
     return NPERR_NO_ERROR;
 }
 
 static NPError nsPostURL (NPP instance, const char *url,
         const char *target, uint32 len, const char *buf, NPBool file) {
-    (void)instance; (void)len; (void)buf; (void)file;
+    (void)instance; (void)file;
     print ("nsPostURL %s %s\n", url, target);
-    addStream (url, 0L, target, 0L, false);
+    addStream (url, 0L, target, len, buf, 0L, false);
     return NPERR_NO_ERROR;
 }
 
@@ -356,9 +368,7 @@ static void nsStatus (NPP instance, const char* message) {
 static const char* nsUserAgent (NPP instance) {
     (void)instance;
     print ("NPN_UserAgent\n");
-    return "Mozilla/4.0 (compatible; MSIE 6.0; X11; Linux armv6l; U) Opera 8.5 [en_US] Tablet browser 0.0.14 RX-34_2007SE_4.2007.26-8";
-    /*return "Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.8.1.3) Gecko/20070310 Iceweasel/2.0.0.3 (Debian-2.0.0.3-1)";
-    return "";*/
+    return "Mozilla/5.0 (X11; U; Linux armv6l; en-US; rv:1.9a6pre) Gecko/20080828 Firefox/3.0a1 Tablet browser 0.3.7 RX-34+RX-44+RX-48_DIABLO_5.2008.43-7";
 }
 
 static uint32 nsMemFlush (uint32 size) {
@@ -386,14 +396,14 @@ static jref nsGetJavaPeer (NPP instance) {
 static NPError nsGetURLNotify (NPP instance, const char* url, const char* target, void *notify) {
     (void)instance;
     print ("NPN_GetURLNotify %s %s\n", url, target);
-    addStream (url, 0L, target, notify, true);
+    addStream (url, 0L, target, 0, NULL, notify, true);
     return NPERR_NO_ERROR;
 }
 
 static NPError nsPostURLNotify (NPP instance, const char* url, const char* target, uint32 len, const char* buf, NPBool file, void *notify) {
-    (void)instance; (void)len; (void)buf; (void)file;
+    (void)instance; (void)file;
     print ("NPN_PostURLNotify\n");
-    addStream (url, 0L, target, notify, true);
+    addStream (url, 0L, target, len, buf, notify, true);
     return NPERR_NO_ERROR;
 }
 
@@ -1025,7 +1035,7 @@ void *nppInstanceOpen (const char *mime, uint16_t argc, char *argn[],
 
 void nppInstanceStart (const char *url, const char *mime, void *pdata) {
     (void) pdata;
-    addStream (url, mime, 0L, 0L, false);
+    addStream (url, mime, 0L, 0, NULL, 0L, false);
 }
 
 void nppStreamData (uint32_t stream, const char *buf, uint32_t sz, void *p) {
