@@ -35,7 +35,7 @@ class ViewAreaPrivate;
 /*
  * The area in which the video widget and controlpanel are laid out
  */
-class KMPLAYER_EXPORT ViewArea {
+class KMPLAYER_NO_EXPORT ViewArea {
 public:
     ViewArea ();
     ~ViewArea ();
